_When adding a new case, please add a short description to this file._

## Available datasets

### Beerwiser 
This case focuses on a (fictional) beer brewer that is interested in comparing the effects of
reducing water use and the amount of workplace accidents. 

### Refugees
The Refugee Accommodation Model helps policy-makers evaluate and make well-considered policy choices 
about incoming refugees. It:

- is a calculation model based on multidisciplinary research - helps to eliminate sentiment from a 
sensitive topic and provide insights based on empirical evidence.
- can be beneficial for any policy maker involved in the refugee-related policies
- assesses the impact of various policy instruments (e.g. language courses for refugees) on the desired outcomes 
(e.g. increase in social cohesion and/or employment among refugees). 
- recognizes that not all outcomes carry the same value for different stakeholders, 
allowing the user to set strategic priorities, against which assessment is made.

### DSM
Royal Dutch multinational corporation (DSM) is a global science-based company active in health, nutrition and materials. This case elaborates the decision making at DSM who wants to anticipate climate change by addressing its own environmental and carbon footprint by means of reducing its greenhouse gas emissions and becoming more energy efficient. Their strategic challenge, therefore, has been formulated as how to source energy:
- No RE: not buy or make renewable energy
- Make RE: make renewable energy
- RE Market: buy renewable energy from the market and buy renewable energy certifications 
- RE Partner: buy renewable energy from partners and buy renewable energy certifications
- RS Partner without REC: buy renewable energy from partners without buying renewable energy certifications
- No RS with REC: buy energy from non-renewable source from market and buy renewable energy certifications


### IZZ
This case demonstrates how IZZ offers healthcare institutions objective insights into what –for them- the optimal 
strategy is with regard to the People pillar, mainly focusing on the employability of their employees. 
There is a serious need for measures that will help achieve a balance between supply and demand in the healthcare 
sector but also to account for the welfare of personnel. IZZ uses the strategic decision making process to support 
many healthcare institutions in finding out what measures will help make healthcare a more pleasant, efficient and 
attractive working environment. 


### NEMO 
This case addresses NEMO's decision making process towards solving its problems with the roof. Recurring leaks have 
required complicated and expensive repairs and the roof also fell short of the insulation standards for this type of 
public building. The strategic decision making process facilitated the expansion plans of NEMO to do more than the 
repair a roof. In the process with the Business Simulator the importance of the public space of the roof and the 
iconic function of the building for the city of Amsterdam was underlined. More intensive use of the roof would also 
lead to more visitors of NEMO. Multi-functionality turned out to be key in the decision making process on the 
investments of the roof. In close collaboration with architect Renzo Piano multiple uses and designs of the roof 
were discussed. The opening of the new roof was in Spring 2016.